==> 1.1.4.0.tar.gz: manufacturer-information/README.md <==
[![deutsche Version](https://logos.oxidmodule.com/de2_xs.svg)](README.md)

# ![D3 Logo](https://logos.oxidmodule.com/d3logo_24x24.svg) Herstellerinformationen für OXID eShop

Fügt die Möglichkeit zur Langtextbeschreibung den Herstellern hinzu. Die Anzeige der Informationen erfolgt einstellbar auf der Herstellerübersicht und/oder als Infotab an den Artikeln der Herstellers.

**Diese Software wird unter einer kommerziellen Lizenz vertrieben.**
Kontaktieren Sie uns für eine Nutzungslizenz vor der Installation.

## Inhaltsverzeichnis

- [Installation](#installation)
- [Lizenz](#lizenz)

## Installation

Dieses Paket erfordert einen mit Composer installierten OXID eShop in einer in der [composer.json](composer.json) definierten Version.

Öffnen Sie eine Kommandozeile und navigieren Sie zum Stammverzeichnis des Shops (Elternverzeichnis von source und vendor). Führen Sie die folgenden Befehle aus. Passen Sie die Pfadangaben an Ihre Installationsumgebung an.

```bash
composer config repositories.d3manufacturerinformation vcs https://git.d3data.de/D3Public/manufacturer-information.git
composer require d3/manufacturerinformation:"~1.1.0"
```

Sofern nötig, bestätigen Sie bitte, dass Sie `package-name` erlauben, Code auszuführen.

```bash
./vendor/bin/oe-eshop-db_migrate migrations:migrate d3manufacturerinformation

./vendor/bin/oe-console o:m:i source/modules/d3/manufacturerinformation
./vendor/bin/oe-console o:m:deact d3manufacturerinformation
./vendor/bin/oe-console o:m:act d3manufacturerinformation

./vendor/bin/oe-eshop-db_views_generate
```

Leeren Sie anschließend den Temp Ordner des Shops.

## Lizenz
(Stand: 13.11.2024)

```
Copyright (c) D3 Data Development (Inh. Thomas Dartsch)

Diese Software wird unter einer kommerziellen Lizenz vertrieben. Die Installation und der Einsatz ist ohne gültige Lizenz nicht gestattet.
```

Die vollständigen Copyright- und Lizenzinformationen entnehmen Sie bitte der [LICENSE](LICENSE.md)-Datei, die mit diesem Quellcode verteilt wurde.

==> 2.0.3.1.tar.gz: manufacturer-information/README.md <==
[![deutsche Version](https://logos.oxidmodule.com/de2_xs.svg)](README.md)

# ![D3 Logo](https://logos.oxidmodule.com/d3logo_24x24.svg) Herstellerinformationen für OXID eShop

Fügt die Möglichkeit zur Langtextbeschreibung den Hersteller hinzu

## Inhaltsverzeichnis

- [Installation](#installation)
- [Lizenz](#lizenz)

## Installation

Dieses Paket erfordert einen mit Composer installierten OXID eShop in einer in der [composer.json](composer.json) definierten Version.

Öffnen Sie eine Kommandozeile und navigieren Sie zum Stammverzeichnis des Shops (Elternverzeichnis von source und vendor). Führen Sie die folgenden Befehle aus. Passen Sie die Pfadangaben an Ihre Installationsumgebung an.


```bash
composer config repositories.d3manufacturerinformation vcs https://git.d3data.de/D3Public/manufacturer-information.git
composer require d3/manufacturerinformation:"~2.0.0"
```

Sofern nötig, bestätigen Sie bitte, dass Sie `package-name` erlauben, Code auszuführen.

```bash
./vendor/bin/oe-eshop-db_migrate migrations:migrate d3manufacturerinformation

./vendor/bin/oe-console oe:module:install vendor/d3/manufacturerinformation
./vendor/bin/oe-console oe:module:deactivate d3manufacturerinformation
./vendor/bin/oe-console oe:module:activate d3manufacturerinformation

./vendor/bin/oe-eshop-db_views_generate
```

Leeren Sie anschließend den Temp Ordner des Shops.


## Lizenz
(Stand: 19.12.2024)

```
Copyright (c) D3 Data Development (Inh. Thomas Dartsch)

Diese Software wird unter einer kommerziellen Lizenz vertrieben. Die Installation und der Einsatz ist ohne gültige Lizenz nicht gestattet.
```

Die vollständigen Copyright- und Lizenzinformationen entnehmen Sie bitte der [LICENSE](LICENSE.md)-Datei, die mit diesem Quellcode verteilt wurde.
